@@ -1,6 +1,6 @@
 package Net::Riak::Role::REST;
 {
-  $Net::Riak::Role::REST::VERSION = '0.1600';
+  $Net::Riak::Role::REST::VERSION = '0.1700';
 }
 
 # ABSTRACT: role for REST operations
@@ -11,8 +11,8 @@ use Moose::Role;
 use MooseX::Types::Moose 'Bool';
 use Net::Riak::Types qw/HTTPResponse HTTPRequest/;
 use Data::Dump 'pp';
-with qw/Net::Riak::Role::REST::Bucket 
-    Net::Riak::Role::REST::Object 
+with qw/Net::Riak::Role::REST::Bucket
+    Net::Riak::Role::REST::Object
     Net::Riak::Role::REST::Link
     Net::Riak::Role::REST::MapReduce
     Net::Riak::Role::REST::Search
@@ -38,6 +38,12 @@ has disable_return_body => (
     default => 0
 );
 
+has ssl => (
+    is => 'rw',
+    isa => Bool,
+    default => 0
+);
+
 sub _build_path {
     my ($self, $path) = @_;
     $path = join('/', @$path);
@@ -47,6 +53,7 @@ sub _build_uri {
     my ($self, $path, $params) = @_;
 
     my $uri = URI->new($self->get_host);
+    if ( $uri =~ /^https:.+/ ) { $self->ssl(1); }
     $uri->path($self->_build_path($path));
     $uri->query_form(%$params);
     $uri;
@@ -64,6 +71,7 @@ sub send_request {
     my ($self, $req) = @_;
 
     $self->http_request($req);
+
     my $r = $self->useragent->request($req);
 
     $self->http_response($r);
@@ -86,7 +94,7 @@ sub all_buckets {
     my $self = shift;
     my $request = $self->new_request('GET', [$self->prefix], {buckets => 'true'});
     my $response = $self->send_request($request);
-    die "Failed to fetch buckets.. are you running riak 0.14+?" 
+    die "Failed to fetch buckets.. are you running riak 0.14+?"
         unless $response->is_success;
     my $resp = JSON::decode_json($response->content);
     return ref ($resp->{buckets}) eq 'ARRAY' ? @{$resp->{buckets}} : ();
@@ -104,6 +112,7 @@ sub stats {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -112,7 +121,7 @@ Net::Riak::Role::REST - role for REST operations
 
 =head1 VERSION
 
-version 0.1600
+version 0.1700
 
 =head1 AUTHOR
 
@@ -126,4 +135,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
