@@ -1,4 +1,7 @@
 package Net::Riak::Role::UserAgent;
+{
+  $Net::Riak::Role::UserAgent::VERSION = '0.1700';
+}
 {
   $Net::Riak::Role::UserAgent::VERSION = '0.1600';
 }
@@ -8,6 +11,8 @@ package Net::Riak::Role::UserAgent;
 use Moose::Role;
 use LWP::UserAgent;
 use LWP::ConnCache;
+use IO::Socket::SSL;
+use Data::Dumper;
 
 our $CONN_CACHE;
 
@@ -19,6 +24,11 @@ has ua_timeout => (
     default => 120
 );
 
+has ssl_opts => (
+    is => 'rw',
+    isa => 'HashRef'
+);
+
 has useragent => (
     is      => 'rw',
     isa     => 'LWP::UserAgent',
@@ -31,11 +41,20 @@ has useragent => (
         my %opts = @LWP::Protocol::http::EXTRA_SOCK_OPTS;
         $opts{MaxLineLength} = 65_536;
         @LWP::Protocol::http::EXTRA_SOCK_OPTS = %opts;
+        my $ua = undef;
 
-        my $ua = LWP::UserAgent->new(
-            timeout => $self->ua_timeout,
-            keep_alive => 1,
-        );
+        if ( !$self->ssl ) {
+            $ua = LWP::UserAgent->new(
+                timeout => $self->ua_timeout,
+                keep_alive => 1,
+            );
+        } else {
+            $ua = LWP::UserAgent->new(
+                timeout => $self->ua_timeout,
+                keep_alive => 1,
+                ssl_opts => $self->ssl_opts
+            );
+        }
 
         $ua->conn_cache(__PACKAGE__->connection_cache);
 
@@ -46,6 +65,7 @@ has useragent => (
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -54,7 +74,7 @@ Net::Riak::Role::UserAgent - useragent for Net::Riak
 
 =head1 VERSION
 
-version 0.1600
+version 0.1700
 
 =head1 AUTHOR
 
@@ -68,4 +88,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
